﻿using System;
using System.Drawing;
using System.IO.Ports;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UFO_APP
{
    public partial class Form1 : Form
    {
        /*
         * Název souboru: UFO_APP
         * Projekt: Návrh a realizace programového vybavení pro testovací platformu Valeo „UFO“
         * Vytvořil: Tomáš Křeček
         * Datum:  14.03.2024
         *
         * Popis:
         * Tato aplikace slouží primárně ke komunikaci s Platformou UFO verze V3 - "V3.01"
         *
         * Licenční informace:
         * Tento soubor je součástí Bakalářské práce ve spolupráci s firmou Valeo. 
         */


        #region ---Defines---
        static int defineReceiveTime = 100; // 100 ms Rychlost přijímání dat po sběrnici
        static string definePortName = "COM3"; //PC port pro spojení s Xbee modulem
        static bool testMode = true; //Testovací verze
        static string appVersion = "V3.01"; //Verze aplikace
        static double UFOWheelebase = 0.8; //Rozchod UFA
        #endregion
        //------------------
        //Definice pro dannou verzi aplikace


        #region ---Variables---
        string message;
        // Message, VersionAPP, VersionUFO, VersionBaseStation ,Connection Xbee, Connection UFO, Connestion Home station,
        // Error UFO, Error Base Station, Error Kill Switch, Error Aplication, Kill Switch PC, Kill switch Modul,
        // Regime type, Scenerio type, Speed scenerio, Distance 1, Distance 2, Radius/Distance 3,
        // Live data:: Speed, wheeleangle, Batery UFO,

        bool error = false;
        bool testError = false;
        bool turning;
        bool turningleft;
        clsResize _form_resize;
        SerialPort serialPort = new SerialPort
        {
            PortName = definePortName,
            BaudRate = 9600,
            Parity = Parity.None,
            DataBits = 8,
            StopBits = StopBits.One,
            Handshake = Handshake.None
        };
        #endregion
        //------------------
        //Globální proměné


        #region ---Serial_Port---
        //Načtení komunikace po seriové lince na XBEE
        private void InitializeSerialPort()
        {
            if (testMode) //Testovací verze
            {
                liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + 
                    " - Serial port Open\n" + liveLogRichTextBox.Text;
            }
            else
            {
                try //Otevření komunikačního kanálu
                {
                    serialPort.PortName = comPortComboBox.Text;
                    serialPort.Open();
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + 
                        " - Serial port Open\n" + liveLogRichTextBox.Text;
                }
                catch (Exception ex) //Chyba v otevírání
                {
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + 
                        " - Can´t open serial port please change COM port: " + ex.Message
                        + "\n" + errorLogRichTextBox.Text;
                    ErrorStatusLabel.BackColor = Color.Red;
                }
            }
        }
        #endregion
        //------------------
        //Inicializace seriového portu



        #region ________Main Form________
        public Form1() //Main form 
        {
            //Inicializace
            InitializeComponent();
            receiveTimer.Interval = defineReceiveTime;
            versionTextBox.Text = appVersion;

            //Změna velikosti okna
            _form_resize = new clsResize(this);
            this.Load += _Load;
            this.Resize += _Resize;
        }

        //Zavírání okna 
        private void Form1_FormClosing(object sender, FormClosingEventArgs e) //Při zavření okna 
        {
            receiveTimer.Stop();  //Zastavení posílání dat
            if (serialPort.IsOpen) serialPort.Close();   //Zavření komunikace
        }

        //Zavírací button
        private void quitButton_Click(object sender, EventArgs e)
        {
            this.Close();
        }
        #endregion
        //-------------------------------------------
        //Main Form Inicializace
        //Zavírání okna
        //Close tlačítko


        #region ________Connect_modules________
        //Connect button
        private void connectButton_Click(object sender, EventArgs e)
        {
            InitializeSerialPort(); //Otevření seriové linky XBEE

            if (serialPort.IsOpen || testMode) //Test otevřenosti / Testovací verze
            {
                if (testConnection() || testMode) //Test komunikace / Testovací verze
                {
                    xbeeLabel.BackColor = Color.LimeGreen;
                    regimeGroupBox.Enabled = true;
                    connectButton.Enabled = false;
                }
                else xbeeLabel.BackColor = Color.Red;
            }
            else
            {
                xbeeLabel.BackColor = Color.Red;
                ErrorStatusLabel.BackColor = Color.Red;
            }
        }
        
        //Test připojení všech komponet UFO, Base station a PC 
        private bool testConnection()
        {
            bool test = true;

            if (testMode) //Testovací verze
            {
                liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Testing connection OK\n" + liveLogRichTextBox.Text;
                xbeeLabel.BackColor = Color.LimeGreen;
                ufoLabel.BackColor = Color.LimeGreen;
                homeStatioLabel.BackColor = Color.LimeGreen;
                return test;
            }
            else
            {
                xbeeLabel.BackColor = Color.LimeGreen;
                serialPort.WriteLine(BuildMessage("Test connection", appVersion, "-", "-", "true", "-", "-", "-", "-", "-",
                    "false", "false", "-", "-", "-", "-", "-", "-", "-", "-", "-", "-"));

                //Zpoždění pro návrat zpravy z home station
                this.Cursor = Cursors.WaitCursor;
                this.Enabled = false;
                Task.Delay(100);
                this.Enabled = true;
                this.Cursor = Cursors.Default;

                //Čtení přijaté zprávy
                string rm = serialPort.ReadLine();
                string[] read_message = rm.Split(';');


                //Testování připojení UFA
                if (read_message[1] == appVersion && read_message[4] == "true")
                {
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Testing connection UFO OK\n"
                        + liveLogRichTextBox.Text;
                    ufoLabel.BackColor = Color.LimeGreen;
                }
                else
                {
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Testing connection UFO FAIL\n"
                        + liveLogRichTextBox.Text;
                    ufoLabel.BackColor = Color.Red;
                    test = false;
                }

                //Testování připojení Home station
                if (read_message[2] == appVersion && read_message[5] == "true")
                {
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Testing connection Home station OK\n"
                        + liveLogRichTextBox.Text;
                    homeStatioLabel.BackColor = Color.LimeGreen;
                }
                else
                {
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Testing connection Home station FAIL\n"
                        + liveLogRichTextBox.Text;
                    homeStatioLabel.BackColor = Color.Red;
                    test = false;
                }
                return test;
            }
        }
        #endregion
        //-------------------------------------------
        //Propojení všech modulů při stisku tlačítka
        //Test připojení všech modulů 


        #region ________Errors_and_Kill_switch________
        //Testování errorů
        private void errorTest(string[] ms)
        {
            if (ms[5] == "false") //UFO erroe
            {
                receiveTimer.Stop();
                ErrorStatusLabel.BackColor = Color.Red;
                ufoLabel.BackColor = Color.Red;
                errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - UFO platform error: " + ms[1]
                    + "\n" + errorLogRichTextBox.Text;
                ClearErrorButton.Enabled = true;
            }

            if (ms[6] == "false") //Base statio error
            {
                receiveTimer.Stop();
                ErrorStatusLabel.BackColor = Color.Red;
                ufoLabel.BackColor = Color.Red;
                errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Base station error: " + ms[1]
                    + "\n" + errorLogRichTextBox.Text;
                ClearErrorButton.Enabled = true;
            }

            if (ms[7] == "false") //Kill switch error
            {
                receiveTimer.Stop();
                ErrorStatusLabel.BackColor = Color.Red;
                ufoLabel.BackColor = Color.Red;
                errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Kill switch error: " + ms[1]
                    + "\n" + errorLogRichTextBox.Text;
                ClearErrorButton.Enabled = true;
            }

            if (ms[9] == "false") //Kill switch modul stisknut
            {
                receiveTimer.Stop();
                ErrorStatusLabel.BackColor = Color.Red;
                ufoLabel.BackColor = Color.Red;
                errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Kill switch pressed: " + ms[1]
                    + "\n" + errorLogRichTextBox.Text;
                ClearErrorButton.Enabled = true;
            }
        }

        //Stisknutí PC kill switche
        private void KillSwitchButton_Click(object sender, EventArgs e)
        {
            receiveTimer.Stop(); //Zastavení přijímaní dat

            //Odeslání zprávy po PC kill switch
            message = "PC Kill switch";
            sendMessage(BuildMessage(message, appVersion, "-", "-", "true", "-", "-", "-",
                "-", "-", "false", "true", "-", "-", "-", "-", "-", "-", "-", "-", "-", "-"));

            //Zápis do live a error logu
            errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") +
                " - Kill switch\n" + errorLogRichTextBox.Text;
            liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") +
                " - Kill switch\n" + liveLogRichTextBox.Text;

            //Úprava zobrazení HUID
            ErrorStatusLabel.BackColor = Color.Red;
            error = true;
            ClearErrorButton.Enabled = true;
            KillSwitchButton.Enabled = false;
            KillSwitchButton.BackColor = Color.Red;
            applicationLabel.BackColor = Color.Red;
        }

        //Vymazání errorů ze všech modulů
        private void ClearErrorButton_Click(object sender, EventArgs e)
        {
            //Úprava zobrazení HUID
            KillSwitchButton.Enabled = true;
            KillSwitchButton.BackColor = SystemColors.Control;
            ErrorStatusLabel.BackColor = Color.LimeGreen;
            error = false;
            ClearErrorButton.Enabled = false;

            //Odeslání zprávy pro vyčištění errorů
            message = "Clear error";
            sendMessage(BuildMessage("Clear error", appVersion, "-", "-", "true",
                "-", "-", "-", "-", "-", "false", "false", "-", "-", "-",
                "-", "-", "-", "-", "-", "-", "-"));

            //Zápis do live a error logu
            errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss")
                + " - Error clear\n" + errorLogRichTextBox.Text;
            liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss")
                + " - Error clear\n" + liveLogRichTextBox.Text;

            //Odemčení možnosti pokračovat dále ve scénáři
            if (!setScenerioGroupBox.Visible) startUfoButton.Enabled = true;
            else
            {
                liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Set scenerio\n" + liveLogRichTextBox.Text;
                scenerioGroupBox.Enabled = true;
                setScenerioGroupBox.Enabled = true;
                testStatusLabel.BackColor = Color.Orange;
            }

            //Úprava zobrazení HUID
            applicationLabel.BackColor = Color.LimeGreen;
            xbeeLabel.BackColor = Color.LimeGreen;
            ufoLabel.BackColor = Color.LimeGreen;
            homeStatioLabel.BackColor = Color.LimeGreen;
        }
        #endregion
        //-------------------------------------------
        //Test zda v nějaký z modulů neposílá error
        //Stisknutí kill switch PC
        //Odstranění všech errorů na všech nodulech


        #region ________Communication________
        //Poslání zprávy
        private bool sendMessage(string ms)
        {
            if (serialPort.IsOpen)
            {
                try
                {
                    //Hlavní komunikace
                    testConnection(); //Kontrola připojení modulů
                    serialPort.WriteLine(ms); //Odeslání zprávy
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Xbee data send\n" + liveLogRichTextBox.Text;
                    return true;
                }
                catch (Exception ex) //Špatně načtený seriový port
                {
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Xbee data can´t bee send: " + ex.Message
                    + "\n" + errorLogRichTextBox.Text;
                    ErrorStatusLabel.BackColor = Color.Red;
                    return false;
                }
            }
            else //Chyba komunikace
            {
                if (testMode) //Testovací verze
                {
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Xbee data send\n" + liveLogRichTextBox.Text;
                    testConnection();
                    return true;
                }
                else //Chyba v komunikaci
                {
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Serial port is not open\n" + errorLogRichTextBox.Text;
                    ErrorStatusLabel.BackColor = Color.Red;
                    return false;
                }
            }
        }

        //Přijímání zpráv po XBEE komunikaci
        private void receiveTimer_Tick(object sender, EventArgs e)
        {
            if (testMode) //Testovací verze
            {
                liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Xbee data received + LIVE DATA\n" + liveLogRichTextBox.Text;
            }
            else
            {
                try
                {
                    //Načtení přijaté zprávy a rozdělení do matice
                    string rm = serialPort.ReadLine();
                    string[] read_message = rm.Split(';');

                    //Test připojených modulů
                    testConnection();

                    //Výpis do live logu
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Xbee data received\n" + "Speed: "
                        + read_message[19] + "; Wheel angle: " + read_message[20] + "; UFO Batery: " + read_message[21] 
                        + liveLogRichTextBox.Text;

                    //Vyhodnocení errorů z přijaté zprávy
                    errorTest(read_message);
                }
                catch (Exception ex) //Data nebyla přijata 
                {
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Xbee not data received: " + ex.Message
                        + "\n" + errorLogRichTextBox.Text;
                    ErrorStatusLabel.BackColor = Color.Red;
                    homeStatioLabel.BackColor = Color.Red;
                    throw;
                }
            }
        }

        //Vytvoření zprávy jako jako jeden string k odeslání
        static string BuildMessage(params string[] parts)
        {
            return String.Join(";", parts);
        }

        //Odeslání startovací zprávy button
        private void startUfoButton_Click(object sender, EventArgs e)
        {
            string scenerio_type = "-";
            string speed_scenerio = "-";
            string distance1 = "-";
            string distance2 = "-";
            string rad_dist3 = "-";
            string regime_type = ModesComboBox.Text;

            scenerioGroupBox.Enabled = false;
            setScenerioGroupBox.Enabled = false;

            //Při zvolení ovládání pomocí RC
            if (ModesComboBox.Text == "Radio control") message = "Radio control";
            else //Při zvolení ovládání pomocí scénářů
            {
                message = "Scenerio";
                scenerio_type = ScenerioComboBox.Text;
                speed_scenerio = speedTextBox.Text;
                distance1 = distance1TextBox.Text;
                distance2 = distance2TextBox.Text;

                //Zatáčecí scénář akrmanova podmínka
                if (ScenerioComboBox.Text != "Driving straight" && scenerioGroupBox.Enabled == true)
                {
                    var angles = countRadiusAkrmans();
                    rad_dist3 = angles[0].ToString() + angles[1].ToString();
                }
                else rad_dist3 = radiusTextBox.Text;
            }

            //Zpráva byla odeslána uspěšně
            if (sendMessage(BuildMessage(message, appVersion, "-", "-", "true", "-", "-", "-", "-",
                "-", "false", "false", "-", regime_type, scenerio_type,
                speed_scenerio, distance1, distance2, rad_dist3, "-", "-", "-")))
            {
                KillSwitchButton.Enabled = true;
                startUfoButton.Enabled = false;
                ErrorStatusLabel.BackColor = Color.LimeGreen;

                receiveTimer.Start(); //Začni přijímat data od Home station
            }
        }

        //Výpočet Akrmanovy podmínky pro zatáčení
        private double[] countRadiusAkrmans()
        {
            double inside_wheel_angle = (Math.Atan(UFOWheelebase /
                (Convert.ToDouble(radiusTextBox.Text) - UFOWheelebase / 2))) * (180 / Math.PI);
            double outside_wheel_angle = (Math.Atan(UFOWheelebase /
                (Convert.ToDouble(radiusTextBox.Text) + UFOWheelebase / 2))) * (180 / Math.PI);
            if (!turningleft) return new[] { inside_wheel_angle, outside_wheel_angle }; //Zatáčka doprava
            else return new[] { outside_wheel_angle, inside_wheel_angle }; //Zatáčka doleva
        }
        #endregion
        //-------------------------------------------
        //Funkce pro odesílání zpráv po komunikační lince
        //Přijímání zpráv a jejich vyhodnocení
        //Pomocná fuknce pro přepis zprávy ve vhodném formátu
        //Startovací tlačítko v aplikaci - Vyhodnotí a pošle vhodnou zprávu
        //Výpočet akrmanovy podmínky pro natočení kol


        #region ________Zobrazování_HUID_Komponent________
        //Načtení vhodného scénáře a zobrazení nákresu scénáře
        private void setScenerioButton_Click(object sender, EventArgs e)
        {
            setScenerioGroupBox.Enabled = true;
            setScenerioGroupBox.Visible = true;
            scenerioPictureBox.Visible = true;

            switch (ScenerioComboBox.Text)
            {
                case "Driving straight": //Jízda rovně
                    turning = false;
                    scenerioPictureBox.BackgroundImage = Image.FromFile(Application.StartupPath + "/straightLinePicture.png");
                    label8.Text = "Distance 3";
                    break;
                case "Left turn": //Levá zatáčka
                    turning = true;
                    turningleft = true;
                    scenerioPictureBox.BackgroundImage = Image.FromFile(Application.StartupPath + "/leftConrnerPicture.png");
                    label8.Text = "Turning radius";
                    break;
                case "Right turn": //Pravá zatáčka
                    turning = true;
                    turningleft = false;
                    scenerioPictureBox.BackgroundImage = Image.FromFile(Application.StartupPath + "/rightConrnerPicture.png");
                    label8.Text = "Turning radius";
                    break;
            }
        }

        //Vybírání režimů button
        private void regimeComfirmButton_Click(object sender, EventArgs e)
        {
            switch (ModesComboBox.Text)
            {
                case "Radio conntrol":
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + 
                        " - Radio conntrol set possible start UFO\n" + liveLogRichTextBox.Text;
                    startUfoButton.Enabled = true;
                    regimeComfirmButton.Enabled = false;
                    regimeGroupBox.Enabled = false;
                    applicationLabel.BackColor = Color.LimeGreen;
                    break;
                case "Scenerio":
                    scenerioGroupBox.Enabled = true;
                    regimeComfirmButton.Enabled = false;
                    regimeGroupBox.Enabled = false;
                    break;
                default:
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") 
                        + " - Pick some regime" + errorLogRichTextBox.Text;
                    break;
            }
        }

        //HUID zobrazování comboboxy
        private void ModesComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            regimeComfirmButton.Enabled = true;
        }

        private void ScenerioComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            setScenerioButton.Enabled = true;
        }

        #endregion
        //-------------------------------------------
        //Zobrazování vhodného nákresu podle zvoleného scénáře
        //Výběr vhodného režimu podle zvoleného comboBoxu
        //Změna pro comboboxy v HUID


        #region ________Dosažitelnost_scénáře________
        //Ověření dosažitelnosti scénáře
        private void testButton_Click(object sender, EventArgs e)
        {
            try
            {
                testError = false;

                //Chybně zadaná vzdálenost 1
                if (0.1 > Convert.ToDouble(distance1TextBox.Text) || 10 < Convert.ToDouble(distance1TextBox.Text))
                {
                    testStatusLabel.BackColor = Color.Red;
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss")
                        + " - Bad distance 1 must be between 0,1m and 10m\n" + errorLogRichTextBox.Text;
                    testError = true;
                }

                //Chybně zadaná vzdálenost 2
                if (0.1 > Convert.ToDouble(distance2TextBox.Text) || 10 < Convert.ToDouble(distance2TextBox.Text))
                {
                    testStatusLabel.BackColor = Color.Red;
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss")
                        + " - Bad distance 2 must be between 0,1m and 10m\n" + errorLogRichTextBox.Text;
                    testError = true;
                }

                //Chybně zadaná rychlost
                if (5 > Convert.ToDouble(speedTextBox.Text) || 45 < Convert.ToDouble(speedTextBox.Text))
                {
                    testStatusLabel.BackColor = Color.Red;
                    errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss")
                        + " - Bad speed must be between 5km/h and 45km/h\n" + errorLogRichTextBox.Text;
                    testError = true;
                }

                //Chybně zadaná vzdálenost 3
                if (ScenerioComboBox.Text == "Driving straight")
                {
                    if (0.1 > Convert.ToDouble(radiusTextBox.Text) || 10 < Convert.ToDouble(radiusTextBox.Text))
                    {
                        testStatusLabel.BackColor = Color.Red;
                        errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss")
                            + " - Bad distance 3 must be between 0,1m and 10m\n" + errorLogRichTextBox.Text;
                        testError = true;
                    }
                }

                //Chybně zadaný rádius
                else
                {
                    if (5 > Convert.ToDouble(radiusTextBox.Text) || 90 < Convert.ToDouble(radiusTextBox.Text))
                    {
                        testStatusLabel.BackColor = Color.Red;
                        errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Radius must be between 5 degree and 90 degree\n" + errorLogRichTextBox.Text;
                        testError = true;
                    }
                }

                //Testovací verze
                if (!testError)
                {
                    testStatusLabel.BackColor = Color.LimeGreen;
                    errorLogRichTextBox.Text = "";
                    liveLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Scenerio set is OK\n" + liveLogRichTextBox.Text;
                    startUfoButton.Enabled = true;
                }
            }
            catch (Exception) //Špatně zadaný vstup
            {
                testStatusLabel.BackColor = Color.Red;
                errorLogRichTextBox.Text = DateTime.Now.ToString("HH:mm:ss") + " - Wrong input\n" + errorLogRichTextBox.Text;
            }
        }

        //Změny v HUID při změně dat
        private void distance1TextBox_TextChanged(object sender, EventArgs e)
        {
            testStatusLabel.BackColor = Color.Orange;
            startUfoButton.Enabled = false;
        }

        private void distance2TextBox_TextChanged(object sender, EventArgs e)
        {
            testStatusLabel.BackColor = Color.Orange;
            startUfoButton.Enabled = false;
        }

        private void radiusTextBox_TextChanged(object sender, EventArgs e)
        {
            testStatusLabel.BackColor = Color.Orange;
            startUfoButton.Enabled = false;
        }

        private void speedTextBox_TextChanged(object sender, EventArgs e)
        {
            testStatusLabel.BackColor = Color.Orange;
            startUfoButton.Enabled = false;
        }
        #endregion
        //-------------------------------------------
        //Kontrola dosažitelnosti
        //Změna huid při změně dat v textbox poli


        #region ________Změna_velikosti_okna________     
        //Načtení velikosti okna
        private void _Load(object sender, EventArgs e)
        {
            _form_resize._get_initial_size();
        }

        //Změna velikosti okna
        private void _Resize(object sender, EventArgs e)
        {
            _form_resize._resize();
        }
        #endregion        
        //-------------------------------------------
        //Inicializace okna pro resize
        //Resize funkce odkazuje na clasu Resize.cs
    }
}
